sqlite

package
v0.0.0-...-d9b39ff Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 12, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCatalog

func NewCatalog() *catalog.Catalog

func NewIdentifier

func NewIdentifier(t string) *ast.String

Types

type Delete_stmt

type Delete_stmt interface {
	Qualified_table_name() parser.IQualified_table_nameContext
	WHERE_() antlr.TerminalNode
	Expr() parser.IExprContext
	// contains filtered or unexported methods
}

type Parser

type Parser struct {
}

func NewParser

func NewParser() *Parser

func (*Parser) Cast

func (p *Parser) Cast(arg, typeName string) string

Cast returns a type cast expression. SQLite uses CAST(expr AS type) syntax.

func (*Parser) CommentSyntax

func (p *Parser) CommentSyntax() source.CommentSyntax

func (*Parser) IsReservedKeyword

func (p *Parser) IsReservedKeyword(s string) bool

https://sqlite.org/lang_keywords.html

func (*Parser) NamedParam

func (p *Parser) NamedParam(name string) string

NamedParam returns the named parameter placeholder for the given name. SQLite uses :name syntax for named parameters.

func (*Parser) Param

func (p *Parser) Param(n int) string

Param returns the parameter placeholder for the given number. SQLite uses ? for positional parameters.

func (*Parser) Parse

func (p *Parser) Parse(r io.Reader) ([]ast.Statement, error)

func (*Parser) QuoteIdent

func (p *Parser) QuoteIdent(s string) string

QuoteIdent returns a quoted identifier if it needs quoting. SQLite uses double quotes for quoting identifiers (SQL standard), though backticks are also supported for MySQL compatibility.

func (*Parser) TypeName

func (p *Parser) TypeName(ns, name string) string

TypeName returns the SQL type name for the given namespace and name.

type Update_stmt

type Update_stmt interface {
	Qualified_table_name() parser.IQualified_table_nameContext
	GetStart() antlr.Token
	AllColumn_name() []parser.IColumn_nameContext
	WHERE_() antlr.TerminalNode
	Expr(i int) parser.IExprContext
	AllExpr() []parser.IExprContext
}

Directories

Path Synopsis

Jump to